# Pyessh
A tool for easy to use SSH execute commands at multi-server.



## Usage

#### Installation

```shell
pip3 install pyessh
```

#### Editing the Configuration File

```shell
vim /etc/local/pyessh.conf
```

add remote server IP addresses at pyessh.conf

```toml
127.0.0.1
...
```

#### Get Started

```python
pyessh
```



## License

MIT